Exceptions
==========

pyHaFAS can raise multiple exceptions. In the message of the exception you can always find the complete text error message HaFAS returned.

.. automodule:: pyhafas.types.exceptions
   :members:
   :undoc-members:
